/**
 * Ooyala marker behavior.
 */
(function ($) {
  Drupal.behaviors.ooyalaMarkersJumpToAttach = {
    attach: function (context, settings) {
      // Find all the chapter marker links.
      $('a.ooyala-markers-marker').click(function() {
        var href = $(this).attr('href');
        var fragment = href.slice(href.indexOf('#') + 1).split(':');
        var apiver = settings.ooyala.ooyala_player_version;

        // Set player based on Ooyala API version
        switch (apiver) {
          case 'v2':
            player = document.getElementById(fragment[0] + '_0_ooyala_player');
            break;
          case 'v3':
            player = document.getElementById('ooyala_player');
            break;
          case 'v4':
            // ooyalaplayers defined for v4 by theme_ooyala_player() in ooyala.module
            $.each(ooyalaplayers, function(i) {
              if ($('#' + ooyalaplayers[i].getElementId()).parents('.field-name-' + fragment[0].replace(/_/g, '-')).length > 0) {
                player = ooyalaplayers[i];
              }
            });
            break;
        }

        if (parseInt(fragment[1])) {
          Drupal.ooyalaMarkersJumpTo(player, fragment[1], apiver);
        }

        // Set the browser's URL so people can link directly to this chapter.
        window.location = href;
        return false;
      });
    }
  };

  /**
   * Tell the video player to jump to the specified time within the current video.
   *
   * @param player
   *   Player DOM object.
   * @param time
   *   Time in milliseconds to jump to.
   */
  Drupal.ooyalaMarkersJumpTo = function(player, time, apiver) {
    // Use the Ooyala V3 "videoPlayer" shortcut if a player is not defined.
    player = (!player && window.videoPlayer) ? window.videoPlayer : player;

    // Jump the player to the appropriate time.
    // The time variable is converted to seconds here. Ooyala API claims that
    // it has millisecond accuracy so we denote times in milliseconds, however
    // the setPlayHeadTime method takes the number of seconds as an argument.
    if (apiver === 'v3') {
      player.pauseMovie();
      player.setPlayheadTime(time/1000);
      player.playMovie();
    } else if (apiver === 'v4') {
      player.play();
      player.seek(time/1000);
      player.play();
    }
  };

  // Initialize Drupal.ooyala if it hasn't been yet since it is possible for this
  // module's javascript to be loadded before ooyala_player.js
  Drupal.ooyala = Drupal.ooyala || {'listeners': {}, 'onCreateHandlers': {}, 'players': {} };

  /**
   * Register V3 event listener for Ooyala API callbacks.
   */
  Drupal.ooyala.onCreateHandlers.ooyalaMarkers = function(player) {
    player.mb.subscribe(OO.EVENTS.PLAYBACK_READY, 'ooyalaMarkers', function(eventName) {
      // If there is a #time in the current href jump to that point in the
      // video.
      var href = window.location.href;
      var fragment = href.slice(href.indexOf('#') + 1).split(':');
      if (fragment[0] && parseInt(fragment[1])) {
        // Apparently "PLAYBACK_READY" isn't quite ready yet, give it .5 second.
        window.setTimeout(function() {
          var $playerWrapper = $(document.getElementById(player.getElementId())).parents('.field-name-' + fragment[0].replace(/_/g, '-'));
          if ($playerWrapper.length > 0) {
            window.scrollTo(0, $playerWrapper.eq(0).offset().top - 20);
            Drupal.ooyalaMarkersJumpTo(player, fragment[1], Drupal.settings.ooyala.ooyala_player_version);
          }
        }, 500);
      }
    });
  };

})(jQuery);
